@@ -5,16 +5,16 @@
  * functions which have been compiled as Tcl modules, using the Tcl
  * interface.
  *
- *     ********************************************************************* 
- *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     *********************************************************************
+ *     * Copyright (C) 1985, 1990 Regents of the University of California. *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  */
 
@@ -29,6 +29,7 @@
 #include "windows/windows.h"
 #include "textio/txcommands.h"
 
+#ifdef EXT2SIM_AUTO
 /*
  * ----------------------------------------------------------------------------
  * CmdAutoExtToSim() --
@@ -59,9 +60,11 @@ CmdAutoExtToSim(w, cmd)
     /* Call function which was originally intended */
 
     if (result == TCL_OK)
-	WindSendCommand(w, cmd);
+	WindSendCommand(w, cmd, FALSE);
 }
+#endif /* EXT2SIM_AUTO */
 
+#ifdef EXT2SPICE_AUTO
 /*
  * ----------------------------------------------------------------------------
  * CmdAutoExtToSpice() --
@@ -92,8 +95,9 @@ CmdAutoExtToSpice(w, cmd)
     /* Call function which was originally intended */
 
     if (result == TCL_OK)
-	WindSendCommand(w, cmd);
+	WindSendCommand(w, cmd, FALSE);
 }
+#endif /* EXT2SPICE_AUTO */
 
 #ifdef ROUTE_AUTO
 /*
@@ -127,7 +131,7 @@ CmdAutoRoute(w, cmd)
     /* Call function which was originally intended */
 
     if (result == TCL_OK)
-	WindSendCommand(w, cmd);
+	WindSendCommand(w, cmd, FALSE);
 }
 #endif  /* ROUTE_AUTO */
 
@@ -162,7 +166,7 @@ CmdAutoPlot(w, cmd)
     /* Call function which was originally intended */
 
     if (result == TCL_OK)
-	WindSendCommand(w, cmd);
+	WindSendCommand(w, cmd, FALSE);
 }
 #endif  /* PLOT_AUTO */
 
@@ -197,7 +201,7 @@ CmdAutoLef(w, cmd)
     /* Call function which was originally intended */
 
     if (result == TCL_OK)
-	WindSendCommand(w, cmd);
+	WindSendCommand(w, cmd, FALSE);
 }
 #endif	/* LEF_AUTO */
 
