@@ -190,6 +190,11 @@ cmdScaleCoord(w, arg, is_relative, is_x, scale)
 		    return round(dval);
 	    }
 	}
+	else if (!strcmp(endptr, "u"))
+	    /* Maybe "u" is too ambiguous but it is very commonly used as
+	     * an abbreviation for "micron".
+	     */
+	    mscale = 1000;
 	else if (!strncmp(endptr, "micron", 6))
 	    mscale = 1000;
 	else if (!strncmp(endptr, "centimicron", 11) || !strcmp(endptr, "cu"))
