@@ -21,15 +21,16 @@
 #include "graphics/graphicsInt.h"
 #include "textio/txcommands.h"
 #include "grTkInt.h"
+#include "grTkCommon.h"
+
 
-
 /*---------------------------------------------------------
  * GrTkDisableTablet:
  *	Turns off the cursor.
  *
  * Results:	None.
  *
- * Side Effects:    None.		
+ * Side Effects:    None.
  *---------------------------------------------------------
  */
 
@@ -38,12 +39,12 @@ GrTkDisableTablet ()
 {
 }
 
-
+
 /*---------------------------------------------------------
  * GrTkEnableTablet:
  *	This routine enables the graphics tablet.
  *
- * Results: 
+ * Results:
  *   	None.
  *
  * Side Effects:
@@ -56,7 +57,7 @@ GrTkEnableTablet ()
 {
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  * grtkGetCursorPos:
@@ -82,11 +83,48 @@ grtkGetCursorPos (mw, p)
     Window win1, win2;
 
     if (mw == NULL) mw = grCurrent.mw;
-    
+    if (mw == NULL) return FALSE;
+
     XQueryPointer(grXdpy, Tk_WindowId((Tk_Window)mw->w_grdata),
 		  &win1, &win2, &x1, &y1,
 		  &x, &y, &buttons);
     p->p_x = x;
-    p->p_y = grMagicToX(y);
+    p->p_y = grXtransY(mw, y);
+
+    return TRUE;
+}
+
+/*
+ * ----------------------------------------------------------------------------
+ * grtkGetCursorRootPos:
+ * 	Read the cursor position in screen root coordinates.
+ *
+ * Results:
+ *	TRUE is returned if the coordinates were succesfully read, FALSE
+ *	otherwise.
+ *
+ * Side effects:
+ *	The parameter is filled in with the cursor position, in the form of
+ *	a point in screen coordinates.
+ * ----------------------------------------------------------------------------
+ */
+
+bool
+grtkGetCursorRootPos (mw, p)
+    MagWindow *mw;
+    Point *p;		/* point to be filled in with root coordinates */
+{
+    int x, y, x1, y1;
+    unsigned int buttons;
+    Window win1, win2;
+
+    if (mw == NULL) mw = grCurrent.mw;
+
+    XQueryPointer(grXdpy, Tk_WindowId((Tk_Window)mw->w_grdata),
+		  &win1, &win2, &x1, &y1,
+		  &x, &y, &buttons);
+    p->p_x = x1;
+    p->p_y = y1;
+
     return TRUE;
 }
